Subject: [bug#62859] [PATCH core-updates] gnu: openldap: core-updates build fixes

From: Brian Cully <[email-masked]>
Date: Sat, 15 Apr 2023 09:52:27 -0400

Change quoting to use gexps, so that ungexping in the build phases doesn't
fail with a syntax error.

Remove references to libldap_r.so and .la, since they're no longer being
built, and manually patching in a .so library when there's no corresponding
.la seems like something that should be removed, with dependent packages
updated, if necessary.

 * gnu/packages/openldap.scm (openldap): update quoting to use gexps, remove
 reference to libldap_r.la, which no longer exists, and remove custom install
 of libldap_r.so.
---
 gnu/packages/openldap.scm | 67 ++++++++++++++++++---------------------
 1 file changed, 30 insertions(+), 37 deletions(-)

diff --git a/gnu/packages/openldap.scm b/gnu/packages/openldap.scm
index 7409848795..4d3810ecfb 100644
--- a/gnu/packages/openldap.scm
+++ b/gnu/packages/openldap.scm
@@ -87,44 +87,37 @@ (define-public openldap
     (inputs (list bdb-5.3 cyrus-sasl gnutls libgcrypt zlib))
     (native-inputs (list libtool groff bdb-5.3))
     (arguments
-     `(#:tests? #f
-       #:configure-flags
-       '("--disable-static"
-         ,@(if (%current-target-system)
-               '("--with-yielding_select=yes"
-                 "ac_cv_func_memcmp_working=yes")
-               '()))
-       ;; Disable install stripping as it breaks cross-compiling.
-       #:make-flags '("STRIP=")
-       #:phases
-       (modify-phases %standard-phases
-         ,@(if (%current-target-system)
-               '((add-before 'configure 'fix-cross-gcc
-                   (lambda* (#:key target #:allow-other-keys)
-                     (setenv "CC" (string-append target "-gcc"))
-                     (setenv "STRIP" (string-append target "-strip")))))
-               '())
-         (add-after 'install 'patch-sasl-path
-           ;; Give -L arguments for cyrus-sasl to avoid propagation.
-           (lambda* (#:key inputs outputs #:allow-other-keys)
-             (let ((out (assoc-ref outputs "out"))
-                   (krb5 (assoc-ref inputs "mit-krb5"))) ;propagated from cyrus-sasl
+     (list
+      #:tests? #f
+      #:configure-flags
+      #~(list "--disable-static"
+              #$@(if (%current-target-system)
+                     '("--with-yielding_select=yes"
+                       "ac_cv_func_memcmp_working=yes")
+                     '()))
+      ;; Disable install stripping as it breaks cross-compiling.
+      #:make-flags
+      #~(list "STRIP=")
+      #:phases
+      #~(modify-phases %standard-phases
+          #$@(if (%current-target-system)
+                 '((add-before 'configure 'fix-cross-gcc
+                     (lambda* (#:key target #:allow-other-keys)
+                       (setenv "CC" (string-append target "-gcc"))
+                       (setenv "STRIP" (string-append target "-strip")))))
+                 '())
+          (add-after 'install 'patch-sasl-path
+            ;; Give -L arguments for cyrus-sasl to avoid propagation.
+            (lambda* (#:key inputs outputs #:allow-other-keys)
+              (let ((krb5 (assoc-ref inputs "mit-krb5"))) ;propagated from cyrus-sasl
 
-               ;; The ancient Libtool bundled with OpenLDAP copies the linker flags
-               ;; from Cyrus-SASL and embeds them into its own .la files.  Add an
-               ;; absolute reference to Kerberos so it does not have to be propagated.
-               (substitute* (map (lambda (f) (string-append out "/" f))
-                                 '("lib/libldap.la" "lib/libldap_r.la"))
-                 (("-lkrb5" lib)
-                  (string-append "-L" krb5 "/lib " lib))))))
-         (add-after 'install 'provide-libldap_r
-           (lambda _
-             ;; The re-entrant libldap_r no longer exists since 2.6
-             ;; as it has become the default: provide a linker alias
-             ;; for now.
-             (call-with-output-file (string-append #$output "/lib/libldap_r.so")
-               (lambda (port)
-                 (format port "INPUT ( libldap.so )~%"))))))))
+                ;; The ancient Libtool bundled with OpenLDAP copies the linker flags
+                ;; from Cyrus-SASL and embeds them into its own .la files.  Add an
+                ;; absolute reference to Kerberos so it does not have to be propagated.
+                (substitute* (map (lambda (f) (string-append #$output "/" f))
+                                  '("lib/libldap.la"))
+                  (("-lkrb5" lib)
+                   (string-append "-L" krb5 "/lib " lib)))))))))
     (synopsis "Implementation of the Lightweight Directory Access Protocol")
     (description
      "OpenLDAP is a free implementation of the Lightweight Directory Access Protocol.")

base-commit: 7ccf9943029747d4ba97160214f895b365511278
prerequisite-patch-id: 3a0a1be9df9a40370ebadd64ad6163c1a4f2bc4d
prerequisite-patch-id: 04bc0329678ccd5fe51be207d86dc8a4ce969c8b
prerequisite-patch-id: 7edab399c6512d85ed849f0877ccc9602888f1c8
-- 
2.39.2